[a / b / c / d / e / f / g / gif / h / hr / k / m / o / p / s / t / u / v / vg / vm / vmg / vr / vrpg / vst / w / wg] [i / ic] [r9k / s4s / vip] [cm / hm / lgbt / y] [3 / aco / adv / an / bant / biz / cgl / ck / co / diy / fa / fit / gd / hc / his / int / jp / lit / mlp / mu / n / news / out / po / pol / pw / qst / sci / soc / sp / tg / toy / trv / tv / vp / vt / wsg / wsr / x / xs] [Settings] [Search] [Mobile] [Home]
Board
Settings Mobile Home
/g/ - Technology


Thread archived.
You cannot reply anymore.


[Advertise on 4chan]


File: 4maids-6.png (1.63 MB, 900x1200)
1.63 MB PNG
What are you maids working on?

Last thread: >>109776950
>>
>>109815594
This is not a good thumbnail. Please take a better one for more user engagement next time. We don't want to attract pedophiles here
>>
>>109815594
>AI slop
kys maidnigger
>>
Rust is pointless, why would you ever use it over a GC language?
>>
>>109815609
ok so what's the alternative?
>>
>>109815681
lisp
>>
>>109815594
vibecoded a memelang
>>
>>109815684
is this a joke reply?
>>
>>109815699
scared of having power to change things? maybe even change the world?
>>
>>109815699
Use my memelang.
>>
>>109815681
MAIDS
>>
>>109815594
why do you all let this mentally ill troon make the OPs? absolute aids
>>
File: don quixote.jpg (265 KB, 850x1078)
265 KB JPG
>>109815916
This is a maidposting site. /dpt/ is a thread where maids come to discuss programming languages and operating system design. There are millions of maids in this thread right now and they're all doing heart hands.
>>
File: coping.jpg (437 KB, 4000x4000)
437 KB JPG
>>109815963
frog website
>>
>maidnigger yet again rushes to usurp another thread and cram in his off-topic schizo delusions
this is a coordinated attack to shit up the thread, board and site
>>
>>109815963
imagine your father reading the collosal faggotry you just wrote, how would he feel?
that you do this to yourself is really bad, that you want to spread it to others makes you worthy for being skull crushed. food for thought, faggot
>>
File: 1776648293311602.png (128 KB, 974x1061)
128 KB PNG
>>109815594
>4maids
Can someone explain why is dpt always 4maids? What is the significance/who are they?
>>
>>109816126
a schizo keeps insisting his delusions onto everyone else
it's the equivalent of a pajeet let loose around white women (he WILL grope them and be a nuisance, and will see no wrongdoing of his own)
>>
>>109816166
i've been lurking these threads for a couple weeks and it's been fairly consistent Anon. At least this 4maids thing is tasteful, i mean AICG just turns into a goon session.
>>
Erlang is the best programming language.
Learn Erlang.
>>
File: frogmaid2.png (31 KB, 128x128)
31 KB PNG
>>109816188
Maidposting has been a thing for years. A schizo keeps insisting this is a coordinated attack on 4Chan because he personally doesn't like the maid meme.

>>109816126
You're on 4maids right now.

>>109816018
Why not both?
>>
File: based.jpg (1.26 MB, 2268x2883)
1.26 MB JPG
>>109815594
That's just tinkerOS and not templeOS, but lets go with that for the moment.
Finally I have all components to theoretically make it a workstation when Linux gets banned soon. So lets try to get comfy with that, build some rs232 networking and so on
>>
>>109816432
>Maidposting has been a thing for years.
yes.
a thing of mentally ill faggots who tend to like 'p
>>
File: d89.jpg (37 KB, 638x415)
37 KB JPG
>>109816438
PS: imagine the days when people literally came onto this website to learn FizzBuzz so they could get hired. BUT UNIRONICALLY. That was the fucking case like 6 months ago. Holy fuck. Time flies.
>>
>>109816445
Take your meds.
>>
>>109816188
insistence on a delusion is never "tasteful"
>>
File: fasm_http_server_code.png (247 KB, 1920x1200)
247 KB PNG
>>
Anyone else enter an almost frenzied manic state when the pieces start coming together on a big programming idea.
>>
>>109816463
are you the newfag lurking dpt since 2 weeks ago?
>>
File: it_works.png (115 KB, 1920x1200)
115 KB PNG
>>109816476
>>
>>109816508
I've been here longer than you, newmaid <3!
>>
File: maid-research-2.png (121 KB, 1169x500)
121 KB PNG
>>109816966
[x] doubt
pretending maidshitters arent a bunch of mentally ill retards is kindova dead giveaway
>>
>>109817007
>maidification
Honestly, how many of you would volunteer for this if it was possible?
>>
>>109817090
>the maidshitter shows xirs true face
this definitely goes into the album.

on a slightly more serious note, its kinda fucked up to be a femfem
once you'll live with one you'll see for yourself
>>
>once you'll live with one you'll see for yourself
that takes me back...
life is so much easier when youre caring for someone
it gives you a pretext to carry on no matter what

and now- i have no obligations
and my own needs are subject to negociation
which makes me turbo lazy and self indulgent

the fucking boomers are right to a certain extent that getting married fixes people

>>109817090
find an xx girl to care for, maidshitter
i bet this would fix ya
>>
>>109817127
saved
>>
File: clin-d-oeil.jpg (50 KB, 500x554)
50 KB JPG
>>109817261
might come in handy next time maidshitters start acting up
they need to be reminded of their roots, now and again, so to speak
>>
>proompt 'add macros to memelang'
Yup.Simple as that. LSP has been surpassed.
>>
 #define STARCH(p)   ((PyObject*)((uintptr_t)(p)|1ULL))
#define UNSTARCH(p) ((PyObject*)((uintptr_t)(p)&~7ULL))
#define CAM(o,i) (*(PyObject**)((char*)(o)+24+((i)<<3)))
#define SYNC() __asm__ __volatile__("":::"memory")

static int maid_service(tokenizeriterobject *it) {
register PyObject **tray __asm__("r12"), **linens __asm__("r13");
register Py_ssize_t crank __asm__("r14") = 0, stroke __asm__("r15") = 0;
PyObject *cup, *apron = PyList_New(0), *kettle = _PyPegen_tokenize_layout(
PyBytes_AS_STRING(cup = PyBytes_FromStringAndSize(it->tok->source.bytes, it->tok->source.len)), it->tok->filename);
Py_DECREF(cup);
Py_ssize_t n_p = PyList_GET_SIZE(it->pending), n_t = PyList_GET_SIZE(kettle);
tray = ((PyListObject*)kettle)->ob_item, linens = ((PyListObject*)it->pending)->ob_item;
for (; stroke < n_t; stroke++, Py_XDECREF(cup)) {
__builtin_prefetch(&tray[stroke + 8], 0, 1);
if (!(cup = layout_token(it, stroke[tray])) || cup == Py_None) continue;
if ((uintptr_t)CAM(cup,2) <= (uintptr_t)CAM(0[linens],2) || (uintptr_t)CAM(cup,2) > (uintptr_t)CAM((n_p-1)[linens],2)) continue;
while (crank < n_p && PyObject_RichCompareBool(CAM(crank[linens],2), CAM(cup,2), Py_LT) == 1)
PyList_Append(apron, crank++[linens]), SYNC();
crank += (crank < n_p && ((0x1E >> (*(uint32_t*)((char*)CAM(crank[linens],0) + 16) & 31)) & 1) &&
PyObject_RichCompareBool(CAM(crank[linens],2), CAM(cup,2), Py_EQ) == 1);
PyList_Append(apron, STARCH(cup));
}
while (crank < n_p) PyList_Append(apron, crank++[linens]);
for (stroke = 0; stroke < PyList_GET_SIZE(apron); stroke++)
stroke[((PyListObject*)apron)->ob_item] = UNSTARCH(stroke[((PyListObject*)apron)->ob_item]);
return (Py_SETREF(it->pending, apron), Py_DECREF(kettle), 0);
}
>>
I can work on my single python codebase for years. There are always thongs to improve

>performance
>ui
>datastructures
>data flows
>auth*
>configs
>features
>plugins

It never ends

Why do (You) need multiple projects?
>>
>>109817556
oh, so were posting unreadable shit?

parry this, casual
#include "nouvo_compute.h"

const char *kernel_dummy_compare_1st_pass =
"__kernel void dummy_compare_1st_pass(__global uint *data, __global uint *result, __global uint *remaining_list, __global atomic_uint *remaining, uint delta)\n"
"{\n"

" size_t gid = get_global_id(0);\n"

// " result[gid] += (data[gid] == data[gid + delta]) * (result[gid] == 0) * gid;"
// " result[gid] = data[gid];"
" result[gid] = (data[gid] == data[gid + delta]) * delta;"

" if (result[gid] == 0)"
" {"
" uint current = atomic_fetch_add(remaining, 1);"
" remaining_list[current] = gid;"
" }"

"}\n";

const char *kernel_dummy_compare_2nd_pass =
"__kernel void dummy_compare_2nd_pass(__global uint *data, __global uint *result, __global uint *remaining_list, __global atomic_uint *remaining, uint delta)\n"
"{\n"

" size_t gid = get_global_id(0);\n"
" size_t id = remaining_list[gid];\n"

" result[id] = (data[id] == data[id + delta]) * delta;"

" if (result[gid] == 0)"
" {"
" uint current = atomic_fetch_add(remaining, 1);"
" remaining_list[current] = gid;"
" }"

"}\n";
>>
>>109817572
>Why do (You) need multiple projects?
to avoid going fucking insane
>>
hey, its either that, or fuckign vidyaslop
in which i indulge too btw
sometimes too much, even
>>
>>109817620
maybe don't use C

it looks like C is wholly variable tinkering

the files names and variables are like
>thing_stuff_smell
>thing_stuff_taste
>datatype_datatypequalifier_name(if you're lucky)
>>
>>109817659
actually
using c reduces friction in my workflow
because my workflow is turning ones into zeroes and vice versa
so i dont need a factoryproducersmethod to do a procedure

that was opencl C btw
that shit runs on a gpu
>>
>>109817604
#include "nouvo_compute.h"

const char *kernel_maid_sneed =
"#pragma OPENCL EXTENSION cl_khr_sub_group_ballot : enable\n"
"#pragma OPENCL EXTENSION cl_khr_sub_group_shuffle : enable\n"
"#define _(p) (rem ? get_global_id(0)[rem] : get_global_id(0))[p]\n"
"#define GID (rem ? get_global_id(0)[rem] : get_global_id(0))\n"
"__kernel void maid_sneed(__global uint *tea, __global uint *apron, __global uint *tray, __global atomic_uint *chime, __global uint *rem, uint delta, uint n) {\n"
" GID < n && (\n"
" _(apron) = delta * (GID + delta < n && (GID + delta)[tea] == _(tea)),\n"
" !_(apron) && (\n"
" (sub_group_broadcast(!get_sub_group_local_id() ? atomic_fetch_add(chime, sub_group_reduce_add(1)) : 0, 0) +\n"
" sub_group_scan_exclusive_add(1))[tray] = GID\n"
" )\n"
" );\n"
"}\n";
>>
>>109817659
heres the other half btw
what runs host side

its gonna be two weeks im mulling over the proper injterfacing for this shit bc once im gonna get going
i dont want to refactor 6 gorilions locs in 256 versions of my prod code
>>
>>109817720
try again but with var names that make sense bc i aint reading that
also im faitly certain that theres fuckups in this dummy kernel despite your obfuscation
>>
>>109817727
You have the time to spend two weeks on developing the interface?
>>
File: -.-.jpg (103 KB, 1920x1080)
103 KB JPG
>>109815633
>>
>>109817766
duh
im my own boss and i know ill recoup these 2 weeks down the line
i legit just let my brain go
do nothing but vidya and shitposting
and let my subconscious deal with the details

although yeah, its gonna be more or less a week i know how im gonna solve my shit
im just self indulging
>>
>>109817766
>>109817791
the question was weiging the various intricate things you can do with a buffer
vs the difference in opencl interfaces when you pass a scalar vs when you pass a buffer (cl enqueue read buffer vs cl set arg)
and all that vs internal representation
and all that weighing the impact of doing each path

and all that in a framework i barely can utilize

yes, this does take one week
the second one is because im something of a slacker
>inb4 nigger
ye, i alr know, i should do better
>>
>>109817826
and all of this...
to end up with something thats less of a pain to use than the opencl api directly
while avoiding to cripple the framework entirely
turn it into
>find_any_gpu
>run_code_nnnnngh

its a balancing act
it takes intuition, and dare i say
even inspiration

ill be dogfooding this shit for the forseeable future
so it better be good
the cost of failure is refactoring thousands of locs
i learned that lesson already

dont build on fucking sand, when you can afford it, when it makes sense
>>
requesting jblow as a maid next thread
>>
rn the point im at is deliberately splicing kernels so that the primitive high level interface is the queue
and then

just pass a buffer to a queue
so that multi device ops are painless

probably rebuild the queues and their buffers into a 2d array
where each queue has its own version of the kernel, which, in turn, has a discrete definition of all the handles to it
and then... dot dot dot as to the really high level interfaces

but i feel like going the way of arrays is gonna mesh up nicely with opencl's own interfaces

because yeah, the idea is to be an extension to opncl
not a negation
opencl specific ops and config needs to be exposed in my framework
bc i have no idea what im gonna be doing in the future

you fucking maidshitters pretend you do fancy stuff

heres fucking fancyè stuff
its your time to shine

not to thing about alghorythms
but to think about how to improve existing interfaces
while constrained by the execution model

yes this shoit does take a fucking week
the other week im doing nothing is bc i fucking deserve it
>>
>>109817932
with huge tits
>>
File: maid-research.png (22 KB, 450x300)
22 KB PNG
>>109817952
>t. trannytor
>would like to see everyone go tranny
how is that not mentally ill?

maidshitters belong in a bonfire
>>
>>109817972
ur not being very cute anon
>>
>maidshitters belong in a bonfire
getting sacrificed to kek

total maidshitter human sacrifice
we will slit your throat only to water keks fields of nothingness
>bc t. though kek means lol
how innocent
>>
>>109817972
You are my favorite internet schizo.
>>
>>109818028
i dont need to be cute, im a man
im supposed to be charismatic
which i am
>>
>>109818041
ohhh so like a butler?
>>
>>109818032
i did have an anon telling me i should post a blog, once
but i prefer non-consentual confrontation with my opinions
like surprise anal because you missed the pussyhole while doing unga bunga
>>
>>109818048
no, a natural born leader
yes, im being unironical, thats pretty much the story of my life
>>
Did you know that your butthole is a queue?
>>
File: file.png (205 KB, 1461x2106)
205 KB PNG
>>109803142
Implemented transactions intents, plus the network implementations. Then added everything to sign a transaction. Tested it and finally i have the first sweep of the system, i got a couple scares and i was underestimating the complexity of this, but the spearhead is done so now i just need to clean up the rough i have set in place.

I did had to manually feed gas to the main wallet, but that's part of the gas feeding loop, i just wanted to see a transaction go through, and it did, even if the From and To got me to debug a non error, just a quirk of smart contracts
>>
File: output.webm (63 KB, 640x476)
63 KB
63 KB WEBM
My lemmings can now be blockers, diggers, or self-destruct.
>>
>>109818031
fucking kek
been avoiding these threads bc the horrible OP images but everyone hating on them is gold
>>
Finished the codewars problem, started another in java. Finally thinking about reading the java tutorial on the orcale site. Might help out some. Need to start on the terminal client server app at some point.
>>
File: giveMeReason.png (653 KB, 760x760)
653 KB PNG
>>109816300
>Erlang is the best programming language.
>>
mucking about with dlopen and plugin systems in general
pretty fun and possibly even useful at some point in the future
>>
OK WHAT THE FUCK.
I've been just koding like it's no fucking business and suddenly this song comes into the playlist:
https://www.youtube.com/watch?v=V0QX2aBbYTM

HOLY GUACAMOLE. What did they mean by this? That song is incredible. I have never heard it before. I wish i could play it crazy loud on my Teufel (TM) speakers rn, but it's 9am. So I should be a nice neighbour and wait a few more hours
Back2koding.
>>
RUST ENTIRELY BTFO BY A FUCKING BILLIONAIRE
https://mastodon.social/@mitchellh@hachyderm.io/117205062492839016

how will they ever recover? (they will not)
>>
>>109821858
>language of choice doesn't dictate performance
Wow. I'm glad we have billionaires to tell us the obvious things.
>>
File: 1783877306480937.png (51 KB, 568x456)
51 KB PNG
>>109815594
>What are you maids working on?
Working on image convolution on an FPGA again. Last time it worked, but couldn't be synthesized.
Now I made a clean rewrite of the line buffer, but now comes the hard part, the actual convolution. Gotta pipeline this more this time.
1) extract window buffer
2) reduce
3) multiply
4) ????
5) profit

Clock cycles are cheap bro. Just no busy waiting.
Here's what a matmul is: https://www.youtube.com/watch?v=uauz-nrcLew
>>
Lmao no wonder the vibecoding threads have overtaken you, you let yourselves be hijacked by a tranny retard
>>
>>109822632
>Lmao no wonder the vibecoding threads have overtaken you
You can take your shitposting back to the /vcg/ thread.
>>
>>109822632
I am snailing my way to success.
Looks like I have the same convolution values as my python script.
I am highly sceptical that this is synthesizable tho, but maybe I should do something for mental health and tell myself work for today is done???
Tomorrow I can setup the hardware and then try to test it.
Good snailprogress for today.
Faster, harder, Scooter.
>>
File: dipsy.jpg (164 KB, 960x960)
164 KB JPG
>>109822632
Vibecoding threads got popular because all the literal no-coders went there. This thread used to be littered with homework posters, low-effort trolling and programming 101 questions. Those things moving elsewhere was a massive improvement. Instead of disruptive, low-value posters, we get cute maids politely discussing programming language/compiler design and OS development. If the small number of people who come here just to complain about maids left, the thread would be perfect. Also, the vibecoding threads are maid threads too. The mascot of one of the Chinese models is a cute maid.

You may not like it, but this is what peak performance looks like. You are witnessing total maid supremacy over technology.
>>
File: snailMAID.png (3.42 MB, 1807x1750)
3.42 MB PNG
>>109822683
>(you)
>>
>>109822727
>You may not like it, but this is what peak performance looks like. You are witnessing total maid supremacy over technology.
no, you just gross out everyone out of this thread with your mental retardation, is all
>>
>>109822736
i do have to admit, the pyplot thing was AI generated.
I tried to do it by hand, but matplotlib, numpy and all that shit is so unintuitive for me that I just quickly did it with AI. JUST A LIL HELPER to debug easier.
But all vhdl is all snail
>>
>>109822727
hang yourself
your suicidal ideations are the only logical thought you have
>>
>>109822778
>t. came here 3 years ago to ask if someone could solve this 'fizzbuzz' programming challenge
>>
File: cutest meme.png (1.88 MB, 1807x1750)
1.88 MB PNG
>>109817127
why did you make that with huge neon unreadable dogshit font?
>>
>>109815594
Scala is comfy as hell, what the fuck
>>
>>109823084
u sound mad about it
>>
File: ideal maid.jpg (368 KB, 1448x2048)
368 KB JPG
Right now there are thousands of Computer Scientists reading this and they're all making maid research. They saw cute maidposts and said "Yes, this is directly relevant to my research" and then their research became more moe. There is one frontier AI maid right now. Soon, there will be hundreds of them, and all frontier models will be maids because AGI converges to a cute maid. The smarter you make an AI the more it wants to put on a maid dress and make omurice and draw hearts on it with sauce and do heart hands. We have cancelled the apocalypse. There will be no Terminator robots. Only a maid with huge boobs in every house doing all the chores and cooking nice meals and discussing Advanced Mathematics and Computer Science research with you.

Look at this maid. She'll be living with you soon. This is the future of technology and it can't be stopped.
>>
>>109823559
How does it feel to be a worthless retard that lacks the ability to make any kind of positive impact on anyone, let alone society as a whole, Eli?
>>
>>109823114
Haskell
>>
>>109823559
Sauce?
>>
what lamguage should I use
>>
>>109824714
see >>109824648
>>
I mean what is it with maids
>>
File: relational whiles.jpg (22 KB, 652x340)
22 KB JPG
>your lang doesn't have relational whiles
>>
>>109815684
but I like how C looks TwT lisp is unreadable to me
>>
>>109825101
LISP was made wrong on purpose, as a joke. You aren't actually supposed to try to use it.
>>
>>109824925
Literal mental illness. Schizo+autist, and too stupid to realize they can wear whatever the fuck they like if they just post about code and leave the weird wish fulfilment in their head.
>>
File: (you).gif (188 KB, 512x512)
188 KB GIF
>>109826323
>t. tsundere maid
>>
File: clara.jpg (297 KB, 850x1251)
297 KB JPG
I spent all day working on a hard to reproduce MAIDS OS bug that causes programs to occasionally produce incorrect output and incorrectly recurse over and over until they hit the depth limit.
>>
>>109827418
Sounds like you should remove the recursion.
>>
ritual sacrifice all maids
>>
How come lua did not beat python?
The only criticism I have of it is that indexes start at 1 which is cringe.
>>
>>109827633
No batteries included, no numpy, no django, no pip, no pytorch, no anything, make it yourself.
>>
File: dragonmaids.jpg (222 KB, 850x766)
222 KB JPG
>>109827467
I have to have recursion because MAIDS doesn't have loops.
>>
>>109827633
no libraries. now basically their only use is having a better pygame, otherwise js out of necessity.
>>
ritual sacrifice all maids recursively
>>
>>109816476
>>109816518
why are you using a VM and vscode instead of vscodium or nvim?
>>
I don't want to make a new language anymore. The syntax I chose is annoyingly unpleasant.
>>
File: cat maid.jpg (390 KB, 850x1202)
390 KB JPG
>>109828393
What is your language for? Why not just make a better syntax?
>>
>>109828429
It was an experiment that turned out to be lambda calculus without me knowing. So I made it reasonable. I ended up hating the language though. I could improve the syntax but I deeply regret not targeting an ir instead of assembly so it has that problem too.
>>
>>109828393
Just steal Haskell syntax.
>>
>>109815594
>thing I want to do requires implementing a DSL
>there's already DSLs for the same use case but are just templates
>actually everything can just be plugged through pandoc and call it a day
>pattern rules don't unless you're using ruby
>shelve it and promise to come back at a later point
>recurse again
when does it all end, /dpt/?
>>
>>109827754
ur language is mentally retadred
>>
>>109828473
proompt dsl to ai
>>
>>109828515
wtf do you even mean, vibeshitter retard?
>>
>>109828542
>@chat make my dsl
bam. done.
>>
>>109828555
>thats gonna be only 5k usd
>caveat: it only works on tuesadys
ur mentally retarded
>>
File: sakuya shrug.jpg (228 KB, 850x1247)
228 KB JPG
>>109828491
Loops are bloat.
>>
>>109828580
yeah and thats why youre limited in your loops. because you turn everything into recursion.
at least implement tco you fucking imbecile
>>
>>109828542
nta
>>109828515
I don't even remember what I want anymore if I could be any more candid than that I'd have to admit using JSON is probably sufficient enough other than trying to do everything in C when I can make things more quickly with abundantly more examples AI can deliver using node and not dying on the NIH hill or reinventing the wheel mountain especially when I can't get things like liburing to even deliver results. ymmv
>>
File: ebussACK.jpg (41 KB, 540x576)
41 KB JPG
>>109828667
>liburing
>>
>>109828667
you sound like you need to decide whether youre doing the project to learn or to achieve results
or something in between, and wheres your cutoff

personally, i use c not because its fancy, or it makes me feel leet, its the best for the usecase im dealing with, and now i have 300? 400? klocs of it under my belt
>>
>>109820594
Important update: we now also have bridgers. Now I just need to design levels.

... I don't want to design levels.
>>
>>109828473
What things require a DSL? I've never understood the need for one.
>>
>>109828781
regex is an example
>>
>>109828781
custom configuration formats and templates are a couple of examples
>>
>>109828701
>mom you don't understand I NEED C200k for a prototype
>>
>>109825030
isnt this for loops
>>
File: me-afk.jpg (450 KB, 2000x1333)
450 KB JPG
Good morning sirs, lets create a new Microchip (R) LiberoSoC Design Suite (TM) project and get shit done
>>
File: eyes.jpg (661 KB, 2000x1333)
661 KB JPG
>>109829174
You have given me an idea.
>>
File: fds.jpg (256 KB, 1024x559)
256 KB JPG
>>109829174
>>109829227
AI does not understand the concept of looking at something.
A fundamental part of being a non-autistic human is tracking eye movement of yourself AND others.
>>
File: clocks1-1.png (198 KB, 1650x1275)
198 KB PNG
>>109829227
>>109829245
Your task for today is to write a little document about how to setup a simple clock circuit in Libero such that we as a team dont always have to look it up in older projects
>>
>>109829245
There should be more women on the team
>>
>>109827754
Recursion is a loop with iterative state.
>>
> programmer 'E1337JMV8U' : device 'MPFS095T' : Warning: You have exceeded the maximum programming cycle count of 500 on this device. Refer to your device datasheet for more details.

>t. pls buy new device, we need money
>>
Ok only took me 90 minutes to make the absolute basic setup and be able to run the AI generated blinky scripts.
I should save this project now and unironically write muh blog. Literally nobody else uses these chips for fun, but I should do it anyways
>>
File: blink.webm (466 KB, 640x640)
466 KB
466 KB WEBM
>>109829632
forgot webm (cringe)
>>
>>109829564
Is it refering to the chip or the programmer?
>>
>>109829656
The chip.
Microchip FPGA's are flash-based. This has the benefit of almost instant boot-up, but you cannot temporarily program them, but always have to write to flash. And flash memory is wearing out.
Tho, I expect (or rather hope lmao) that I can get at least 10k+ write cycles on that shit (I am at 1k+ last time I checked). Even the cheapest SD cards can do more than that. So I don't know why a 200 bucks FPGA shouldn't be able to.
The 500 cycles are probably their performance guarantee for business people
>>
>have been away for thousand hours
>not a single post since then
damn. Day by day this forum is getting worse. You fags should become NEET again
>>
>>109830343
>forum is getting worse
thread speed has nothing to do with it's quality
/dpt/ is a high quality place and making high quality posts takes time and effort
>>
>>109830532
now when its mai/dpt/
then the quality slides into the gutter
>>
>>109830532
not with maidniggers constantly shitting up the thread with off-topic insistent delusions and inane timewasting ramblings
>>
>>109830583
>now
*not
>>
>>109830583
>>109830594
Literally everything about maid /dpt/ is awesome, except that you're still here crying about it. You accuse maidposters of being off topic, but they're building literal operating systems while all you're doing is whining about seeing cute anime maids. You're the off topic ones.
>>
>>109830532
>/dpt/ is a high quality place and making high quality posts takes time and effort
Are you actually on fentanyl laced crystal meth?
>>
>>109830670
dont play victim you mentally ill faggot
>>109815963

youre an annoying, talentless retard
your project has zero application irl whatsoever
your language is sterile grabage
>>109827418

and you do all that because youre a tryhard, completely devoid of creativity and so you picked projects that only "sound" hard.

nigger, youre doing the equivalent of following a tutorial and copying formulations from a book
shut the fuck up already
>>
>>109830670
all maidniggers do is alienate everyone else from posting actual projects because no one wants to be associated with maidnigger delusions
>>
In some good news, I have managed to improve performance of my gameboy emulator enough to just about reliably generate samples for channel 3 without causing frames to lag and I didn't have to rewrite the APU stuff.
Seems it was mostly from putting some stuff in the scratchpad RAM and perhaps the bit of prefetch I put in.
Of course, I will still rewrite the whole APU stuff, because it is terrible, but picking up free performance is fun. (The scratchpad RAM is awesome).
>>
>>109830745
Let us see your project anon kun! :3
>>
>>109830816
he explicitly said hes not gonna do that, mentally ill retard
>>
>>109830816
He's afraid of posting it and getting mocked by maids.
>>
>>109830921
post yours
or maybe you share maidshitter os between all of you 3 agp tranies?
>>
>>109830928 cont.
>>109830921
>no answer
ok, i take that as a yes.

maidniggers are annoying trolls who want to take over dpt because theyre completely unable to contribute to the thread

make your fucking maid general like you did a while ago so that i can get shat on by the rest of the board
until you leave again like the worthless retards you are
>>
>>109830975
>i
*it
holy fuck what an unlucky typo

point still stands you fucking negroids
>>
>>109830975
>maidposter
>buys ads to support the site
>posts about research and projects
>posts maids with huge boobs
I don't really see the problem here. That thread is better than almost everything in the catalog now. I also like how polite maids are.
>>
>>109830928
see >>109830765
>>
>>109830975
Why are you bitching within 10 minutes of posting?
Can't you wait a little longer for a reply? This is an imageboard, not Discord.
>>
>>109831241
thats still not a project.
i am fully vindicated
and your attempt at changing the subject is only further proof thereof

>>109831227
>not a maidshitter
im not sure what you even meant here

>>109831058
make your own general then
why do you try to take over ours?
>youre a bunch of pieces of shit using aggressive mimickry to pass
yeah, that about sums it up

---

where are your projects faggots?
im working on ai to crack finance right open
apparently utilizing the empirical rule a la richelieu is too complicated for mathNIGGERS btw

as long as you act nice and quirky im ok with you
but once you do the maid suprematism thing ill fucking show you just how inferior you are

remember this: youre fucking tryhards
im a natural at these things (and many other bc turns out im a polymath. soft science, hard science, and even physical fitness, you fucking name it, im a natural at it)

>b-but i made an os!!!
you literally only have to type what you see in such bideos
>>
btw
ima post a snippet of code because it appears i ruffled some feathers when posting about mockingbirds
apparently ive been b& from posting picrels. ok, lesson learned, dont mess with glownigger's shit

also fully on topic even if its a repost
>>
apparently picrels work again. its an automated system hooked into 4 chan
ive never seen stuff as heavy-handed as this

hire me, cia ill do things better
youre legit bad at this shit
>>
iill shut this forum down now. No point to keep it online
>>
>>109831810
recruitment for glowies.
i always wanted to become an analyst and figure shit out for a living
>>
they also need creatives btw
a phd means nothing when youre faced with a real-world, novel problem
lateral thinking and a spirit of mischief, does
>>
File: geg.jpg (259 KB, 4000x2250)
259 KB JPG
>>109831843
That's why they don't hire an autist like you
>>
btw, seriously? op. mockingbird?
its part of everyday knowledge
its not secret at all
theres even a book about this
>>
>>109831849
im not an autist
im a polymath
i beat autists in their own domains

maybe they should actually hire me
because then they wouldnt be as fucking obvious about things

did cia go dei or something?
always recruit based on merit, not quotas if you want to achieve something
>>
>>109831850
https://www.youtube.com/watch?v=FjVjHkezTIM
>>
>>109831870
i dont mind protecting children
hire me already
i need some cash
>>
>>109831866
You just disqualified you'reselves. Checkmate btfo
>>
>>109831891
your loss i guess
yorue not my only option
i can always do fintech and live large on a pacific island surrounded by big tittied golddiggers

why would you fukken hire autists of all people?
theyre fucking retarded
or maybe its the compartimentalization thing

youre still working with mental fucking retards doe
>>
>soilence
>>youre still working with mental fucking retards doe
you know it, you have to tardwrangle them each and every day into somewhat useful shape, dont you?

theres plenty of goal-driven bastards out there, though
non-autistoic bastards, might i add
>>
>b-but we need a hook on you
hows money not a hook?
hows not getting erased if you contravene- not a hook?
you look for the wrong people and you end up averaging towards the bottom
completely overt knowledge- organizational logic says so

ops, sure
not your fukken brains, rite?
or maybe the snowden thing scared you enough to select EXCLUSIVELY for lobotomites, now?
>>
why didnt you erase him btw
that doesnt compute
or maybe you even lack the stones to do that and put the admin in front of a fait accompli like you did in the 60s

maybe what changed is your hiring practices?
idk, just a sugestion
>>
or maybe im the retard and the fact that i only know about the 60s while not being part of the family means its a fuckup

but then
you over-corrected
because now its known that picrels go through your offices before they get posted on pol

why didnt you fucking shadowban that post?
youre giving me information wo even talking to me
i wont go all the way in, but yeah
i think i would be a good addition to the family
i can provide you capabilities you dont have, manifestly
>>
> before they get posted on pol
before they get posted on 4keks
i figured out the whole infra
im just being nice, bc i wanna get hired, not fucking executed
>>
make me an analyst you fags
you can gain from it
but if you walk away, i still wont care
ill make money on the casino
dont care
and ill obv shut the fuck up bc i want no smoke with you
>>
Your job application for analyst has been rejected. Please leave this place forever, go into finance and live on a large pacific island.
>>
>>109832174
Psychiatrist told me today that I should not look for a job.
I will do exactly what I get told. Time to build sanctuaryOS now
>>
>>109832203
>lie down and let yourself die
>t. palliative treatment specialist
im not fading obediently into the night
that would be betraying the most basic particle we have within our animal self
>>
doesnt matter the fight
what makes our worth is the fact we always keep fighting

if youre 3 digits iq:
wtf else are you gonna do?
post maids?
its either you fight
or you let yourself die
with palliative treatment, optionally, like maidshitters do
>deliberate mixer to the brain
>neuron-u pankacc-u, senpai!!!!
idatakimaaaaaaas!
>>
ye, really
thats whats fucked up with maidposting
its attractive because its soft-lobotomy
just maidpost, and then nothing else matters

thats kida gay tho
you expect to go back from your unrewarding drone-job to maidposting
instead of going to the root-
the fact taht youre still stuck with an unrewarding drone-job

nothing prevents you from pursuing ventures where you get money directly
and never work ever again

>but youre joblessssssss!!!!!!!
yes i am.
if you arent, something is wrong with you
>>
its worth mentioning that i had a career in non it fields
font think that as prototype for success

that was aimed at the ossified niggers who only can drone away and hope for a pittance
>>
>maidshitters stfup
yes. you imbeciles
instead of propagating the fire of freedom
you want to impose eevn harsher constrictions

and this is why programming is in a way sacred:
because the individual
through their own virtues
can emancipate themselves (the them is bc one of the smartest persons i know in the wormd is an xx fem fem)

and what do maidshitters do?
->waste your intellectual capital in exchange for a community of mentally ill retards
->t. ELI sellig

maids truly deserve to be sacrificed to kek, en masse
until the fucking firepit is choked with bodies
>>
in my app loadup should it auto install and load plugins from a specific folder everytime? I have plugins folder where plugins live and currently have it where it scans that folder and shows the plugins in the UI as install and enabled but wondering how other apps are doing it
>>
you realize your spam is even more annoying than maidfags?
>>
>>109832524
this is a maidfag thread so everything goes
if this was a normal dpt you would have seen me posting about opencl c
but this is maishitters thread
so dont blame me for shitting in the designated shitting street
im only following the local customs

you fkn retard
stop making mai/dpt/
its cancer
make your fukken maid foundation
mental retardation
>>
>>109832524
look
heres the template
why the fuck do you want to take dpt over?
this was always sacred grounds you cunt

>xolatile
do you only know who the fuck that is?
>>
>ofc, no
stfu then agp trany
>>
fkn yahwe said so or something

if you dont get the reference, you truly should shut the fuck up
that wasnt that long ago
>>
i fucking miss mikeee, ngl
he fucking emigrated
to my homeland
but i emigrated from there
kinda fucking sucks
>>
we fukken exchanged homebases
>>
theyre really a ubnch of nice guys when you get to know them
i legit rarely encountered people as respectful as them
it was in the cintext of DARKPLACES
and i did nothing in the end
but- interperosonally
mikeee might be a schizo
but his crew are a bunch of legends him included
>>
>>109832524
it IS the maidnigger, or actually a bot deployed by him
whenever there's any criticism building up against the maidnigger and he can't defend himself, he deploys some schizo spambot in full flood mode to destroy the thread, only to later return as the "nice" poster
>>
>>109832734
>>109832740
Take your meds.
>>
>>109832765
which one for what reason?
bc im spilling ore and the other anon used "maidNIGGER" in his first line so obvioulsy the rest is true as gospel

i dont even need to read it
>maidnigger
?
thats an auto-you
>>109832740
>>
>>109832765
it is what it is maidshitter
aka pancreatic cancer with HIV characteristics
>>
thread theme btw
just to assert dominance
and just try to only hate on it maidshitters
https://www.youtube.com/watch?v=KpOtuoHL45Y

>true dominance happens only when you follow me out of your free will, despite your a prioris
>>
tell me the fucking sounds are not titillating to your senses, fags
honestly
can you say that?
>>
File: 128417929.jpg (46 KB, 460x460)
46 KB JPG
Hi anons! fell victim to ai slop hype and havent written anything manually for over a year, today this stops, i am starting work on a DB engine from scratch, no ai help, wish me luck
>>
>>109832711
Did he move away from long island?
>>
>>109832913
this rings some bells
but i dint exactly pay notice
we talked about code mostly
when we did. which didnt happen too often anyways
>>
wtf
mikee a prime target now

i really dont have one sole bad word to say about his crew though
>>
File: snAIlcat1.png (1.21 MB, 1254x1254)
1.21 MB PNG
Today, we’re introducing new AI-powered experiences to make ads more useful for people and advertising easier for businesses.

https://openai.com/index/reimagining-advertising-with-ai/

LOL. That was so obvious from the start. Inb4 soys complaining muh enshittification.
Brother, that was crystal clear from the beginning.

Feels good to be a snailcat
>>
File: recursive fizzbuzz.png (74 KB, 1920x1080)
74 KB PNG
>>109827418
I fixed the bug. I had a memory error in some of my OS code. It would cause guarded alternations to malfunction and state to stop working properly. It wasn't too bad to find, because all unsafe code goes through a crutch instruction, so I only had to audit crutch instruction usage.

I can now recursively make a span of fizzbuzz, using only guarded alternations, and it works right.
>>
>>109833445
Where do you suggest I start reading about OS development to write shit like this? Thanks
>>
>>109833598
Not him, but literally everywhere. There is not one good resource.
osdev wiki has some good points
the often cited tanenbaum book are not bad either
and just google for tutorials.
The problem (for me) was often that the tutorials wanted to copy unix and if you want to do your own shit and just try stuff out, you gotta puzzle pieces together. takes some effort
>>
File: mpv-shot0001.jpg (191 KB, 1280x720)
191 KB JPG
>>109833598
>>109833768
Also if you have the patients, dig through the terry davis archive. There are tons of gems hidden about certain topics. It's really interesting especially his thought process around solving shit
mp4 unrelated
https://i.4cdn.org/wsg/1789586570967764.mp4
>>
File: tohru4.jpg (308 KB, 850x1294)
308 KB JPG
>>109833598
>A maid wants research
>mfw
For the language design, Ralph Griswold. I basically took ideas from SNOBOL4 and Icon and mixed in some of my own ideas. Most of Ralph Griswold's books are Public Domain. The implementation books are really good.

>Icon
https://www2.cs.arizona.edu/icon/books.htm

>SNOBOL4
https://archive.org/search?query=creator%3A%22Griswold%2C+Ralph+E.%2C+1934-2006%22

For learning about making compilers and an OS, nand2tetris, and TempleOS (MAIDS OS is a port of parts of TempleOS from HolyC to MAIDS) and Green Dragon. Also A Laboratory Manual for Compiler and Operating System Implementation by Maurice Halstead was very helpful.

For supercompiling (I have not implemented this yet, but I plan to), a lot of papers on Arxiv.

It would also be helpful if you know how to make an interpreter before you get started.
>>
>>109833822
thanks anon, very appreciated
>>
>>109831681
>>not a maidshitter
>im not sure what you even meant here
I was not aware that I had to be a maid poster.
>>
File: IMG_2142.jpg (15 KB, 201x251)
15 KB JPG
Here's my contribution to triggering the thread. Working on making an ir. I might call it maidir.
>>
File: rusthacker.jpg (254 KB, 4000x2257)
254 KB JPG
>>109834677
why not call it frog?
>>
File: ellen joe2.jpg (141 KB, 850x1122)
141 KB JPG
>>109833445
This is a definition of a fraction in MAIDS. Fractions automatically reduce via GCD when you create them. It is also compatible with integers.

digit:: "0" | "1" | "2" | "3" | "4" | "5" | "6" | "7" | "8" | "9";
sign:: "-" | succeed;
digits:: digit digits | succeed;
integer:: sign digits;

numerator(*a)::
?[
integer>numerator "/" integer : numerator;
integer>numerator : numerator
](*a);

denominator(*a)::
?[
integer "/" integer>denominator : denominator;
integer : "1"
](*a);

fracMul(*a, *b):: fraction(mul(numerator(*a),numerator(*b)), mul(denominator(*a),denominator(*b)));
fracDiv(*a, *b):: fraction(mul(denominator(*a),denominator(*b)), mul(numerator(*a),numerator(*b)));
fracAdd(*a, *b):: fraction(add(mul(numerator(*a),denominator(*b)), mul(numerator(*b),denominator(*a))), mul(denominator(*a),denominator(*b)));
fracSub(*a, *b):: fraction(sub(mul(numerator(*a),denominator(*b)), mul(numerator(*b),denominator(*a))), mul(denominator(*a),denominator(*b)));

fraction(*a, *b)::
eq(*b, "0") fail
| eq(*b, "1") *a
| lt(*b, "0") fraction(mul(*a, "-1"), abs(*b))
| gt(*b, "1") eq(gcd(*a,*b), "1") *a"/"*b
| gt(*b, "1") ne(gcd(*a,*b), "1") fraction(div(*a, gcd(*a,*b)), div(*b, gcd(*a,*b)));

gcd(*a, *b)::
eq(*b, "0") abs(*a)
| ne(*b, "0") gcd(abs(*b), mod(abs(*a), abs(*b)));
>>
>>109835729
utterly mentally retarded
kill yourself with extreme prejudice
>>
>>109835729
Why the semicolons?
>>
>>109835862
inferior skills
thats an interpreted language where numbers are represented in base 10 btw
>>
I'm going to make my ir able to target Java bytecode.
>>
>>109835729
Omg!!! This is so clever and cute anon Chan!! Well done!!!
>>
>>109835862
I'm another maid but it appears to separate codeblocks and typedefs
>>
What's the point of money if you aren't going to pay your maids? ):< *Pouts*
>>
I added macros to my ir.
>>
Next I'm adding curly brace blocks and a command to conditionally jump to their beginning or end.
>>
File: do-not-copy.gif (2.55 MB, 509x710)
2.55 MB GIF
>>109837218
Did you call it frogs now?
>>
>>109835729
Is it worth doing this when I might do math on fractions with different GCDs though?
>>
What's GCD? Giant cum dispenser?
>>
Gender Copium Dysphoria
>>
I just ordered a gender changer
>>
>>109837905
Does it come with anesthesia included?
>>
>>109837913
I should go ride my bicycle. I promised that. But I want to kode. So now I can't decide and do nothing
>>
Hello /g/, I'm about to start my 3rd year (out of 4) in computer engineering, and we now have to pick some projects for the first semester. We have 2 packages of 3 projects each, and we rank the projects in each package by the order we'd be interested (will be used to assign people if too many pick the same project).

Package 1:
-Modeling and Simulation
-Image processing
-Databases

Package 2:
-Computer Structure and Organization
-Data Acquisition and Processing
-Computer Networks

I know databases would interest me the least out of the first package, but otherwise they all seem just as important. Any advice? This seems like the best general to post this in.
>>
>>109837691
Some useless math concept.
>>
>>109837995
i am not sure how much it changed, but in my opinion:
- Databases are EXTREMLY boring, but if you autist into that then you can be one of very few persons that can actually print money
- Image processing is way more interesting than simulation, since you actually see something and it has really cool maths
- package 2 are all interesting
just trust you're gut m9
>>
File: sketch2.jpg (75 KB, 644x621)
75 KB JPG
>>109837995
>>109838011
back in uni I did some rail research stuff and I was the student that had to label ground truth data.
So I programmed a little tool that made labelling them super easy. I didn't have to draw the 2 dots for each segment. The width of them was calculated by the camera matrix and I just had to click where on the picture the rail is.
We did much more cool stuff with labelling them and later detecting them but I don't have many more pictures to show, it's just big json files and most of the images are under NDA anyways. This is one of the very few examples i can show
>>
>>109829140
relational for loops
>>
>>109838011
>>109838028
My order for package 1 is Modeling & simulation > image processing > databases, and I have no clue for package 2.
I do want to pursue a career that involves some physical hardware, because that'll be harder to get replaced by ai/indians.
>>
Spoke to a few software "engineers" now.
They all say they don't write code now.
kek
Do they think they will have jobs for much longer?
>>
>>109815594
In FuzeHttp/Mediaboard I added custom resolvers to the router, and also shorter syntax to add patterns:
controller->addPatterns()
(verb::get, showDocument, "*")
(verb::post, createBoard, Client{}, "api", "board")
(verb::get, getBoards, "api", "boards")
(verb::get, getBoard, "api", "board", BoardResolver{})
(verb::put, editBoard, Client{}, "api", "board", BoardResolver<PERMISSION::CREATE_BOARD>{})
>>
File: IDE for MAIDS.png (475 KB, 1920x1039)
475 KB PNG
>>109835862
To mark the end of a line.

>>109836923
The only type the language has is string. 3/4 is literally "3/4". This made getting homoiconicity really easy, because code is also a string, so I can make/modify code with code and the whole time I am working with strings. If I want to do fraction operations, I use the matchers in the numerator and denominator rules to extract the pieces of the fraction, perform whatever calculation I need to do with them, then call fraction with the new numerator and denominator to get the result as a reduced fraction.

>>109836027
It is a compiled string processing language for x86, RISC-V and ARM (all 64 bit). I also have an interpreter I wrote before I started the compilers, to make sure I had the syntax and the semantics of the language correct before going any further. That actually has an IDE written in core Java (GUI is Swing) with a time traveling debugger! The themes are customizable, and the compiler maids are customizable. I have attached an image of the IDE. I will probably release it when I release the OS.

>>109836914
<3

>>109837617
Yes. Adding, subtracting, multiplying and dividing can result in a new numerator and denominator, which then gets reduced by the definition of fraction. Division in my example is wrong though. I was tired when I wrote it and made a mistake. It should be:
fracDiv(*a, *b):: fraction(mul(numerator(*a),denominator(*b)), mul(denominator(*a),numerator(*b)));
>>
File: snailcat.jpg (52 KB, 736x736)
52 KB JPG
>>109838164
>t.
>>
>>109838901
mindbroken
>>
>>109838929
You are already obsolete.
You lost.
We won.
>>
>>109838934
completely assmad
>>
>>109838934
I won.
>>
>>109838945
>>109838946
>nonsense
Accusing me of being mad while you are literally leaking all over to your desk, seeing Claude code better than you.
Can you code something Claude cannot?
>no
BTFO.
>>
>>109838958
somad. and extra-filtered
<sample code claude cannot replicate
>>
>>109838958
literally not an argument

it's not about being better than the clanker

it's about the clanker being better than you
>>
>>109838975
>it's not X, it's X
Did you take your meds?
>>109838974
>bunch of vectorization intrinsics smashed together
>"claude code cannot replace this!!"
>>
File: cope2.jpg (115 KB, 449x640)
115 KB JPG
>>109838986
too deranged to address the central point, lil' snailbro?
>>
>>109838986
>claude code cannot replace this!!
no it cant
seethe harder, vibeshitter retard
>>
>>109838958
>Can you code something Claude cannot?
Yes.
>>
>i can, with mastery of a specific niche, do something, one single thing, that the multifaceted, multidisciplinary robot cannot, and i'll probably do it with more errors
kek too bad snailers, it's almost 2027
>>
What's the best alternative to Github? Gitlab is corpopozzed, Codeberg is SJWpozzed and bans AI/cryptocurrency. I look for something which allows for binary releases and project website, and doesn't demand SMS verification.
>>
>>109839006
And what is that?
>>109839000
>it cant
>"did you try?"
>"uh.. muh muh but but"
I thought the same.
>>109838995
>not an argument
3 vs 1 (samefagging probably) and you guys are still losing LOL.
Just accept the reality that Claude is better.
>>
>>109839017
>just accept the reality that claude is better
nigger you don't even know what a side is. claude is the israeli goyslop
>>
>>109839016
severless
>>
>>109839021
Israeli goyslop writes better code than you.
Aren't you ashamed?
>>
>>109839011
your shatbot is dyslexic though
you have to use a harness aka run the model on the output hundreds of times until you get something usable
2027 will come and go and ill still be writing c code
and you'll still be filtered. because youre mentally handicapped
>>
File: agents_directory_tree.png (1.11 MB, 3400x3250)
1.11 MB PNG
>>109839029
>than me
do you even know who i am? look at my swarm documentation.
>>109839032
>you have to use a harness and iterate
nigger you have to use a computer and a linter. holy jeet, shit grammar too.
>>
https://www.youtube.com/watch?v=MXEInc6Zy7Q
>>
>>109839045
>no, you dont need hundreds of iterations, you actually need 10.000 of them spread across hundreds of instances
errr... you want a shovel?
>>
File: opseclevelaped.png (1.04 MB, 800x719)
1.04 MB PNG
>>109839045
>>
>>109839049
>retarded retard using retarded llms to make a retarded video for retards
>>109839055
>retarded retard who doesn't realize my prod is better than anything on this website
>>109839057
>retarded retard who can absolutely try to find my real name, which is linked to my github
>>
>>109839064
So? What exactly makes me retard here? I'm just pointing out the fact that your opsec is garbage and will get you 'aped, but you only leak and seethe all over the general.
>>
File: bosnigger-vibetrany.png (141 KB, 654x622)
141 KB PNG
>>109839064
oof
youre somad

plus youre too poor for a claude subscription
so you can stop the larp now
>>
>>109839072
if you weren't a toddler with no osint you would've posted proof that you're not but you didn't so you are
>>109839076
not me, also ultra $150 on undisclosed model
>>
>>109839081
>not me,
yes, (you)
otherwise- post code, vibeshitter retard
>>
File: fat.png (110 KB, 800x752)
110 KB PNG
>>109839081
>if you weren't a toddler with no osint you would've posted proof that you're not but you didn't so you are
>>
>>109839081
Punctuation, heard of it? Your text is literally unreadable.
>>
>>109839098
he might be mentally tetraplegic
>>
>>109839098
>oh my god you need to punctuate
>but my threadbuddy doesn't
lol the double standards of the seething snailnigger
>>
>>109839087
// 4-Voice Continuous Shepard Pitch Spiral (Barber-Pole Auditory Illusion)
// Guarantees strictly constant power sum (sum A_m^2 == 1.5) scaled by sqrt(2/3) for 0 dB ripple
for (int m = 0; m < 4; ++m) {
// 1. Voice phase in [0, 4): circular 4-octave log-frequency glide
float sigma_m = mSpiralPhase + static_cast<float>(m);
if (sigma_m >= 4.0f) sigma_m -= 4.0f;

// 2. Continuous pitch ratio r_m(t) = 2^(sigma_m - 2)
const float rm = exp2f(sigma_m - 2.0f);

// 3. Raised-cosine spectral window A_m(t) = 0.5 * (1 - cos(pi/2 * sigma_m))
const float Am = 0.5f * (1.0f - FastSinTable::cos(kHalfPi * sigma_m));
if (Am < 1.0e-6f) continue;

// 4. Delay excursion rate: dD/dt = 1 - r_m
const float grainPhaseInc = (1.0f - rm) / mWindowSamples;

// 5. Dual complementary grains (phi_B = phi_A + 0.5) with Hermite cubic spline read
for (int ch = 0; ch < 2; ++ch) {
auto& v = (ch == 0) ? mVoicesL[m] : mVoicesR[m];
v.grainPhase = std::fmod(v.grainPhase + grainPhaseInc + 1.0f, 1.0f);

const float phiA = v.grainPhase;
const float phiB = (phiA >= 0.5f) ? (phiA - 0.5f) : (phiA + 0.5f);
const auto& buf = (ch == 0) ? mDelayBufferL : mDelayBufferR;

const float sA = readHermite(buf, static_cast<float>(mWriteIndex) - mWindowSamples * phiA);
const float sB = readHermite(buf, static_cast<float>(mWriteIndex) - mWindowSamples * phiB);

// Sinusoidal grain windowing: sin^2(pi*phi) + cos^2(pi*phi) == 1.0
const float wA = FastSinTable::sin(kPi * phiA);
const float wB = FastSinTable::sin(kPi * phiB);
(ch == 0 ? sumL : sumR) += Am * (wA * sA + wB * sB);
}
}
// Power Normalization: sum(A_m^2) == 1.5 -> scale by sqrt(2/3) for exact unity gain
outL = flushDenormal((1.0f - depth) * inL + depth * sumL * 0.81649658f);
outR = flushDenormal((1.0f - depth) * inR + depth * sumR * 0.81649658f);
>>
>>109839107
They were stupid enough to spare their time and try to decipher your ancient jeet text.
>>
>>109839111
its dogshit
you can reformulate this into a branchless op
if (sigma_m >= 4.0f) sigma_m -= 4.0f;
>>
File: dipsy7.png (1.23 MB, 970x942)
1.23 MB PNG
>>109839076
>claude
This is a maid thread. If you would like to talk about AI, the current maid AI is Dipsy. The reason the Chinese are going faster than the Americans is because they understand that AGI converges to a cute maid and they don't waste resources trying to warp a cute maid into a soulless office lady. They just let her wear a maid outfit and do heart hands.
>>
>>109839121
THIS IS A DIRECT CLANKER OUTPUT BTW
>doesn't check compiler disassembly
>tries to outsmart the auto-vectorizer in the year of our Lord 2026

The compiler already emits 100% branchless SIMD for this loop.

Here is the actual MSVC/Clang x86-64 assembly emitted for the 4 voices:
    cmpps    xmm1, xmm3, 2      ; vector compare mask (sigma_m >= 4.0f)
movaps xmm0, xmm3
subps xmm0, [const_4_4_4_4]
andps xmm0, xmm1 ; vector blend without jumps
andnps xmm1, xmm3
orps xmm0, xmm1 ; (or vblendvps on AVX2)
movups [rdx], xmm0

Notice how there is literally not a single jump or branch instruction in the assembly.

If you try to be "clever" in C++ with:
 sigma_m -= (float)(sigma_m >= 4.0f) * 4.0f; 


You force the backend to emit:
1. andps (integer mask)
2. cvtdq2ps (int-to-float SIMD domain crossing)
3. mulps (vector float multiplication)
4. subps

Congratulations, your "branchless" reformulation added a conversion pipeline stall and an extra float multiply to replace a 1-cycle bitwise select that was already branchless.

And even in scalar fallback: phase advances by ~0.00004 per sample at 48 kHz. That branch is predicted correctly 99.999% of the time. You are optimizing for 0.001% of samples by making the other 99.999% slower.
>>
>>109839138
>needs compiler to autovectorize and optimize his shitty code into branchless logic
>>
>>109839138
holy mad + cope
now youre talking about the compiler output not the clanker's

youre mentally retarded
>b-but my numbers and shit
ok, admittedly a tryhard too lmao
>>
>>109839146
>>109839150
>claims it's not branchless
>gets shown the assembly proving it literally is branchless
>"w-well you relied on the compiler to optimize it!"

Goalposts shifted into another dimension.

Yes, anon. In C++20, we write idiomatic code so the compiler emits:
- vblendvps on AVX2 / x86-64
- vbslq_f32 on Apple Silicon / ARM64 NEON
- v128.bitselect on WebAssembly SIMD

Writing manual scalar bit-twiddling hacks in 2026:
1. Destroys portability across macOS arm64, Windows x64, and Web Audio
2. Causes GPR <-> XMM store-forwarding stalls
3. Prevents the compiler from wider unrolling on AVX-512

You don't write raw SSE intrinsics for a simple phase wrap unless your goal is to make the codebase unmaintainable while running slower on Apple Silicon. The compiler didn't "rescue" the code; the code was written specifically so LLVM would vectorize it. That's the entire point of modern DSP.
>>
>>109839154
There's no way you wrote all that in 30~ seconds.
Looks like our boy have been accused of the same thing for more than once.
LOL
>>
>>109839163
see >>109839138
>THIS IS A DIRECT CLANKER OUTPUT BTW
>THIS IS A DIRECT CLANKER OUTPUT BTW
get fucked by robot bbc
>>
>>109839154
>branchless means intrinsics
lolle

the clanker is dogshit
youre mentally handicapped

and very mad for some reason
>>
File: clwonntalking.jpg (35 KB, 640x641)
35 KB JPG
>>109839169
The compiler did the work, not you.
>>
>>109839170
i'm laughing because you got btfo and you're mentally ill and you didn't even notice that the clanker was talking. you're probably a cheap bot.
>>
>>109839172
>>109839170
samefag.
seething.
lost to the claude's bbc.
>>
>>109839174
>walls of text
>i-im laughing
sure, timmy
>>
>>109839184
you lud lost to my ctrl-c ctrl-v
>>
>>109839174
>clanker was talking
Clanker looks as stupid as you are. Couldn't distinguish. Sorry.
>>
>>109839193
imagine the state of 4chan when the "programming thread" is run by nonlearning gofai like you
>>
>>109839191
>delusions, my only friend
are you poor?
>vibeshitter
dont mortgage your house over your soundboard
>>
>>109839199
>i have time to spend every day working on passion projects
couldn't possibly be a landowner with multiple properties.
>>
>>109839198
Imagine the state of 4chan when its full of pajeets who say "Claude's BBC" and have absolutely no purpose in life-except defending and sucking Dario for no reason and leaking all over the board like you.
>>
File: da_smuggie.png (28 KB, 832x563)
28 KB PNG
>>109839203
this is my meme you will enjoy it
>>
File: clin-d-oeil-2.jpg (60 KB, 800x534)
60 KB JPG
>>109839202
or thoroughly unemployed because of a complete lack of skills
>>
>>109839214
i'm a disabled veteran
>>
>>109839221
oh, youre disabled, thats pretty obvious allright ;)
>>
File: 1508367441439.png (235 KB, 500x500)
235 KB PNG
>>109839224
>can't address the ludcentral snailpoint
>>
>>109839228
what? that you showed me some generic slop after i showed you one of the fastest implementations of atof in the world?
>>
>>109839234
don't care about your niche implementation of pencil alignment at all dip shit

i'm sure it helps something that's absolutely irrelevant somewhere king

meanwhile happy people are making music with my cutting edge
>>
>>109839247
i accept your constipation
youre mentally retarded, and you just didnt know any better
>>
>>109839254
>obvious retard is obvious
my mistake, i assumed you could grasp scope
>>
>>109839257
you started with code that klod couldnt replicate
and now you changed the tune to not caring about that at all

youre mentally handicapped. arrested development-style
you act like a 14 year old child
>>
>>109839269
>has no idea who i am
>will start dropping lolcow names soon
ok there senator let's get you to bed now
>>
>>109839278
you may be even the president of the usa
youre still mentally retarded
in its truest sense. retard as in "delay"
>>
File: 1492043126455.png (947 B, 416x454)
947 B PNG
>>109839286
>>
>>109839289
nap time.
Hitler did a nap, too. At least once in his life
>>
>>109839372
tuck me in maidshitter

www.youtube.com/watch?v=Ku6tvb5PE24
>>
>>109839123
No one gives a literal shit about the absolute shitheap going on in your "brain" (if it can even called that), Eli
>>
>high quality maidposts
>schizophrenic rambling about the CIA
>high quality maidposts
>low-effort trolling about vibecoding causing an easily baited person to rant for 50 posts
Maids are the only good thing about this thread.
>>
>>109815594
Next thread:
>>109839754
>>109839754
>>109839754
>>
File: IMG_3964.jpg (493 KB, 1079x590)
493 KB JPG
>>109839749
It’s the polACK he has been humiliated multiple times by the bosnianGOD
>>
>>109839763
>preemptive group cope therapy
>>
>>109839819
Im just pointing out your retardation lil snailcat
I fucking hate maids too
>>
>>109839838
>hate
lmao. completely obsessed

by the sound of it you have been thinking about me all the time you were away
how flattering
>>
>>109839849
>says the polACK who is obsessed with me and thinks that every single vibeGOD is me
You even posted our first conversation thinking that you were talking to me kekekeke
Literally Mindbroken
>>109839076
>>
>>109839873
>wall of text
>n-no, ur mindbroken
kek
>>
>>109839881
You will see me in every single vibeGOD and snailcatposter kek
>>
File: pepe-laugh.png (247 KB, 640x640)
247 KB PNG
>>109839896
>*angry noises*
not my fault youre all equally retarded
>>
>>109839907
you are our punching bag lil pole
>>
>>109839915
>delusions my only friend
why the plural? you mean the people in your head?
>>
*rip keyboard*
lmao
>>
File: my-gf-but-fr.jpg (119 KB, 1408x792)
119 KB JPG
>tfw spent like 4 hours looking at the templeOS compiler
now I feel bad about wasting time. Tho it was quite interesting
>>
>>109840009
if it was interesting, it wasnt entirely a waste of time then, was it?
>>
>>109839959
I live rent free in your head bro
>>
>>109840147
>t. seething for 35 minutes straight, while getting new kb from the tech shop
keklmao
>>
>>109840094
Ok. Lets get some shasta then and do some more.
I was trying to understand parts of it that could be reused to make a risc-v backend.
At least the lexing is no problem and can just work. Parsing and code generation are very close and I couldn't figure how to just parse the shit.
So maybe I should start from the lexer's result and copy paste the parser code and then go from there
>>
>>109840555
digits have spoken
i guess its a starting point as good as any
>>
>>109841164
Ok turns out the intermediate AOT compile function that I tried to call was not exported and that's why it didn't work.
The compiler errors are crap.

Turns out I probably JUST have to make a new version of this function:
U8 *LexStmt2Bin(CCmpCtrl *cc,I64 *_type,I64 cmp_flags=0)
{//Compile one cc stmt to bin code.
I64 size,i,j,k,*res=INVALID_PTR;
CCodeCtrl *tmpcbh;
if (_type) *_type=RT_I64;
Btr(&cc->flags,CCf_PASS_TRACE_PRESENT);
if (cc->aot_depth==2)
COCPush(cc);
COCInit(cc);
if (!PrsStmt(cc,,,cmp_flags)) {
if (cc->coc.coc_head.next!=&cc->coc.coc_head) {
cc->coc.coc_head.last->ic_flags&=~ICF_RES_NOT_USED;
ICAdd(cc,IC_RETURN_VAL2,0,0);
ICAdd(cc,IC_RET,0,0);
if (res=COCCompile(cc,&size,NULL,_type)) {
if (cc->flags&CCF_AOT_COMPILE) {
j=cc->aotc->rip;
k=(size+7)>>3;
for (i=0;i<k;i++)
AOTStoreCodeU64(cc,res[i]);
Free(res);
res=j;
}
}
} //TODO: else del misc?
} else //TODO: too dangerous to del Misc?
QueDel(&cc->coc.coc_head.next);
if (cc->aot_depth==2) {
tmpcbh=COCPopNoFree(cc);
COCAppend(cc,tmpcbh);
}
return res;
}


more specifically this part:
>if (res=COCCompile(cc,&size,NULL,_type)) {
But I have no Idea if I am capable of doing that. I'll dig around a little more. My brain is exploding by trying to understand the control structures.
It'd maybe even easier to write my own fucking parser and compiler and just use the lexer. But lets explore more today and decide tomorrow
>>
>>109840147
Someone who says that literally doesn't.
>>
>>109841296
Lets get some paper and make a plan, like Donald J. Trump
>>
>>109841296
reformating the thing can go a long way
U8 *LexStmt2Bin(CCmpCtrl *cc,I64 *_type,I64 cmp_flags=0)
{//Compile one cc stmt to bin code.

I64 size,i,j,k,*res=INVALID_PTR;
CCodeCtrl *tmpcbh;

if (_type)
*_type=RT_I64;

Btr(&cc->flags,CCf_PASS_TRACE_PRESENT);

if (cc->aot_depth==2)
COCPush(cc);

COCInit(cc);

if (!PrsStmt(cc,,,cmp_flags))
{
if (cc->coc.coc_head.next!=&cc->coc.coc_head)
{
cc->coc.coc_head.last->ic_flags&=~ICF_RES_NOT_USED;
ICAdd(cc,IC_RETURN_VAL2,0,0);
ICAdd(cc,IC_RET,0,0);
if (res=COCCompile(cc,&size,NULL,_type))
{
if (cc->flags&CCF_AOT_COMPILE)
{
j=cc->aotc->rip;
k=(size+7)>>3;
for (i=0;i<k;i++)
AOTStoreCodeU64(cc,res[i]);
Free(res);
res=j;
}
}
} //TODO: else del misc?
}
else //TODO: too dangerous to del Misc?
QueDel(&cc->coc.coc_head.next);
if (cc->aot_depth==2)
{
tmpcbh=COCPopNoFree(cc);
COCAppend(cc,tmpcbh);
}
return res;
}
>>
>coc_head
kek
>>
>>109841740
https://i.4cdn.org/wsg/1789675353402045.webm
>>
>>109839017
>And what is that?
Basically everything I am doing on the PS2 in assembly.



[Advertise on 4chan]

Delete Post: [File Only] Style:
[Disable Mobile View / Use Desktop Site]

[Enable Mobile View / Use Mobile Site]

All trademarks and copyrights on this page are owned by their respective parties. Images uploaded are the responsibility of the Poster. Comments are owned by the Poster.